summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--ANNOUNCE18
-rw-r--r--CHANGES2
-rw-r--r--CMakeLists.txt2
-rw-r--r--INSTALL4
-rw-r--r--LICENSE2
-rw-r--r--Makefile.am2
-rw-r--r--Makefile.in2
-rw-r--r--README12
-rwxr-xr-xconfigure22
-rw-r--r--configure.ac4
-rw-r--r--libpng-1.4.13beta03.txt (renamed from libpng-1.4.13beta02.txt)8
-rw-r--r--libpng.316
-rw-r--r--libpngpf.32
-rw-r--r--png.c6
-rw-r--r--png.h18
-rw-r--r--pngconf.h2
-rw-r--r--pngpriv.h2
-rw-r--r--pngtest.c2
-rw-r--r--projects/vstudio/readme.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt12
-rwxr-xr-xscripts/libpng-config-head.in2
-rw-r--r--scripts/libpng.pc.in2
-rw-r--r--scripts/makefile.ne12bsd2
-rw-r--r--scripts/makefile.netbsd2
-rw-r--r--scripts/makefile.openbsd2
-rw-r--r--scripts/png32ce.def2
-rw-r--r--scripts/pngos2.def2
-rw-r--r--scripts/pngwin.def2
29 files changed, 81 insertions, 77 deletions
diff --git a/ANNOUNCE b/ANNOUNCE
index 52fed7d19..63c171479 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,5 +1,5 @@
-Libpng 1.4.13beta02 - January 22, 2013
+Libpng 1.4.13beta03 - January 22, 2013
This is not intended to be a public release. It will be replaced
within a few weeks by a public version or by another test version.
@@ -9,20 +9,20 @@ Files available for download:
Source files with LF line endings (for Unix/Linux) and with a
"configure" script
- 1.4.13beta02.tar.xz (LZMA-compressed, recommended)
- 1.4.13beta02.tar.gz
- 1.4.13beta02.tar.bz2
+ 1.4.13beta03.tar.xz (LZMA-compressed, recommended)
+ 1.4.13beta03.tar.gz
+ 1.4.13beta03.tar.bz2
Source files with CRLF line endings (for Windows), without the
"configure" script
- lp1413b02.7z (LZMA-compressed, recommended)
- lp1413b02.zip
+ lp1413b03.7z (LZMA-compressed, recommended)
+ lp1413b03.zip
Other information:
- 1.4.13beta02-README.txt
- 1.4.13beta02-LICENSE.txt
+ 1.4.13beta03-README.txt
+ 1.4.13beta03-LICENSE.txt
Changes since the last public release (1.4.11):
@@ -42,6 +42,8 @@ version 1.4.13beta02 [January 22, 2013]
in configure.ac
Changed default value of PNG_USER_CACHE_MAX from 0 to 32767 in pngconf.h.
+version 1.4.13beta03 [January 22, 2013]
+
Send comments/corrections/commendations to glennrp at users.sourceforge.net
or to png-mng-implement at lists.sf.net (subscription required; visit
https://lists.sourceforge.net/lists/listinfo/png-mng-implement).
diff --git a/CHANGES b/CHANGES
index 2b48e9cd4..38cc76699 100644
--- a/CHANGES
+++ b/CHANGES
@@ -2884,6 +2884,8 @@ version 1.4.13beta02 [January 22, 2013]
in configure.ac
Changed default value of PNG_USER_CACHE_MAX from 0 to 32767 in pngconf.h.
+version 1.4.13beta03 [January 22, 2013]
+
Send comments/corrections/commendations to glennrp at users.sourceforge.net
or to png-mng-implement at lists.sf.net (subscription required; visit
https://lists.sourceforge.net/lists/listinfo/png-mng-implement).
diff --git a/CMakeLists.txt b/CMakeLists.txt
index d9e1454a4..4886f7581 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -255,7 +255,7 @@ install(CODE ${PNG_CONFIG_INSTALL_CODE})
# SET UP LINKS
if(PNG_SHARED)
set_target_properties(${PNG_LIB_NAME} PROPERTIES
-# VERSION 14.${PNGLIB_RELEASE}.1.4.13beta02
+# VERSION 14.${PNGLIB_RELEASE}.1.4.13beta03
VERSION 14.${PNGLIB_RELEASE}.0
SOVERSION 14
CLEAN_DIRECT_OUTPUT 1)
diff --git a/INSTALL b/INSTALL
index 5e91c2119..436834f8e 100644
--- a/INSTALL
+++ b/INSTALL
@@ -1,5 +1,5 @@
-Installing libpng version 1.4.13beta02 - January 22, 2013
+Installing libpng version 1.4.13beta03 - January 22, 2013
On Unix/Linux and similar systems, you can simply type
@@ -46,7 +46,7 @@ to have access to the zlib.h and zconf.h include files that
correspond to the version of zlib that's installed.
You can rename the directories that you downloaded (they
-might be called "libpng-1.4.13beta02" or "libpng14" and "zlib-1.2.3"
+might be called "libpng-1.4.13beta03" or "libpng14" and "zlib-1.2.3"
or "zlib123") so that you have directories called "zlib" and "libpng".
Your directory structure should look like this:
diff --git a/LICENSE b/LICENSE
index ee9369164..53d1b9ce1 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.4.13beta02, January 22, 2013, are
+libpng versions 1.2.6, August 15, 2004, through 1.4.13beta03, January 22, 2013, are
Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
diff --git a/Makefile.am b/Makefile.am
index 7eeb6d438..a312288f2 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -79,7 +79,7 @@ EXTRA_DIST= \
${srcdir}/contrib/pngsuite/* \
${srcdir}/contrib/visupng/* \
$(TESTS) \
- example.c libpng-1.4.13beta02.txt
+ example.c libpng-1.4.13beta03.txt
CLEANFILES= pngout.png libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@.pc libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@-config libpng.vers \
libpng.sym
diff --git a/Makefile.in b/Makefile.in
index ce39e67c6..cf84c1716 100644
--- a/Makefile.in
+++ b/Makefile.in
@@ -332,7 +332,7 @@ EXTRA_DIST = \
${srcdir}/contrib/pngsuite/* \
${srcdir}/contrib/visupng/* \
$(TESTS) \
- example.c libpng-1.4.13beta02.txt
+ example.c libpng-1.4.13beta03.txt
CLEANFILES = pngout.png libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@.pc libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@-config libpng.vers \
libpng.sym
diff --git a/README b/README
index 7508779ad..b21532091 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.4.13beta02 - January 22, 2013 (shared library 14.0)
+README for libpng version 1.4.13beta03 - January 22, 2013 (shared library 14.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
@@ -182,9 +182,9 @@ Files in this distribution:
makefile.std => Generic UNIX makefile (cc, creates static
libpng.a)
makefile.elf => Linux/ELF makefile symbol versioning,
- (gcc, creates libpng14.so.14.1.4.13beta02)
+ (gcc, creates libpng14.so.14.1.4.13beta03)
makefile.linux => Linux/ELF makefile
- (gcc, creates libpng14.so.14.1.4.13beta02)
+ (gcc, creates libpng14.so.14.1.4.13beta03)
makefile.gcc => Generic makefile (gcc, creates static libpng.a)
makefile.knr => Archaic UNIX Makefile that converts files with
ansi2knr (Requires ansi2knr.c from
@@ -206,12 +206,12 @@ Files in this distribution:
makefile.openbsd => OpenBSD makefile
makefile.sgi => Silicon Graphics IRIX (cc, creates static lib)
makefile.sggcc => Silicon Graphics
- (gcc, creates libpng14.so.14.1.4.13beta02)
+ (gcc, creates libpng14.so.14.1.4.13beta03)
makefile.sunos => Sun makefile
makefile.solaris => Solaris 2.X makefile
- (gcc, creates libpng14.so.14.1.4.13beta02)
+ (gcc, creates libpng14.so.14.1.4.13beta03)
makefile.so9 => Solaris 9 makefile
- (gcc, creates libpng14.so.14.1.4.13beta02)
+ (gcc, creates libpng14.so.14.1.4.13beta03)
makefile.32sunu => Sun Ultra 32-bit makefile
makefile.64sunu => Sun Ultra 64-bit makefile
makefile.sco => For SCO OSr5 ELF and Unixware 7 with Native cc
diff --git a/configure b/configure
index 735d72071..ec3d9269a 100755
--- a/configure
+++ b/configure
@@ -1,6 +1,6 @@
#! /bin/sh
# Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.65 for libpng 1.4.13beta02.
+# Generated by GNU Autoconf 2.65 for libpng 1.4.13beta03.
#
# Report bugs to <png-mng-implement@lists.sourceforge.net>.
#
@@ -562,8 +562,8 @@ MAKEFLAGS=
# Identity of this package.
PACKAGE_NAME='libpng'
PACKAGE_TARNAME='libpng'
-PACKAGE_VERSION='1.4.13beta02'
-PACKAGE_STRING='libpng 1.4.13beta02'
+PACKAGE_VERSION='1.4.13beta03'
+PACKAGE_STRING='libpng 1.4.13beta03'
PACKAGE_BUGREPORT='png-mng-implement@lists.sourceforge.net'
PACKAGE_URL=''
@@ -1292,7 +1292,7 @@ if test "$ac_init_help" = "long"; then
# Omit some internal or obsolete options to make the list less imposing.
# This message is too long to be a string in the A/UX 3.1 sh.
cat <<_ACEOF
-\`configure' configures libpng 1.4.13beta02 to adapt to many kinds of systems.
+\`configure' configures libpng 1.4.13beta03 to adapt to many kinds of systems.
Usage: $0 [OPTION]... [VAR=VALUE]...
@@ -1362,7 +1362,7 @@ fi
if test -n "$ac_init_help"; then
case $ac_init_help in
- short | recursive ) echo "Configuration of libpng 1.4.13beta02:";;
+ short | recursive ) echo "Configuration of libpng 1.4.13beta03:";;
esac
cat <<\_ACEOF
@@ -1467,7 +1467,7 @@ fi
test -n "$ac_init_help" && exit $ac_status
if $ac_init_version; then
cat <<\_ACEOF
-libpng configure 1.4.13beta02
+libpng configure 1.4.13beta03
generated by GNU Autoconf 2.65
Copyright (C) 2009 Free Software Foundation, Inc.
@@ -1892,7 +1892,7 @@ cat >config.log <<_ACEOF
This file contains any messages produced by compilers while
running configure, to aid debugging if configure makes a mistake.
-It was created by libpng $as_me 1.4.13beta02, which was
+It was created by libpng $as_me 1.4.13beta03, which was
generated by GNU Autoconf 2.65. Invocation command line was
$ $0 $@
@@ -2700,7 +2700,7 @@ fi
# Define the identity of the package.
PACKAGE='libpng'
- VERSION='1.4.13beta02'
+ VERSION='1.4.13beta03'
cat >>confdefs.h <<_ACEOF
@@ -2764,7 +2764,7 @@ fi
-PNGLIB_VERSION=1.4.13beta02
+PNGLIB_VERSION=1.4.13beta03
PNGLIB_MAJOR=1
PNGLIB_MINOR=4
PNGLIB_RELEASE=13
@@ -12175,7 +12175,7 @@ cat >>$CONFIG_STATUS <<\_ACEOF || ac_write_fail=1
# report actual input values of CONFIG_FILES etc. instead of their
# values after options handling.
ac_log="
-This file was extended by libpng $as_me 1.4.13beta02, which was
+This file was extended by libpng $as_me 1.4.13beta03, which was
generated by GNU Autoconf 2.65. Invocation command line was
CONFIG_FILES = $CONFIG_FILES
@@ -12241,7 +12241,7 @@ _ACEOF
cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
ac_cs_version="\\
-libpng config.status 1.4.13beta02
+libpng config.status 1.4.13beta03
configured by $0, generated by GNU Autoconf 2.65,
with options \\"\$ac_cs_config\\"
diff --git a/configure.ac b/configure.ac
index ff344658a..adf9b3371 100644
--- a/configure.ac
+++ b/configure.ac
@@ -16,14 +16,14 @@ dnl should not be necessary to regenerate configure if the time
dnl stamps are correct
AC_PREREQ(2.59)
-AC_INIT([libpng], [1.4.13beta02], [png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng], [1.4.13beta03], [png-mng-implement@lists.sourceforge.net])
AM_INIT_AUTOMAKE
dnl stop configure from automagically running automake
AM_MAINTAINER_MODE
dnl Version number stuff here:
-PNGLIB_VERSION=1.4.13beta02
+PNGLIB_VERSION=1.4.13beta03
PNGLIB_MAJOR=1
PNGLIB_MINOR=4
PNGLIB_RELEASE=13
diff --git a/libpng-1.4.13beta02.txt b/libpng-1.4.13beta03.txt
index 9df175d54..72de257b9 100644
--- a/libpng-1.4.13beta02.txt
+++ b/libpng-1.4.13beta03.txt
@@ -1,6 +1,6 @@
libpng.txt - A description on how to use and modify libpng
- libpng version 1.4.13beta02 - January 22, 2013
+ libpng version 1.4.13beta03 - January 22, 2013
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2013 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ libpng.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.4.13beta02 - January 22, 2013
+ libpng versions 0.97, January 1998, through 1.4.13beta03 - January 22, 2013
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2010 Glenn Randers-Pehrson
@@ -906,7 +906,7 @@ things.
As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
added. It expands the sample depth without changing tRNS to alpha.
-As of libpng version 1.4.13beta02, not all possible expansions are supported.
+As of libpng version 1.4.13beta03, not all possible expansions are supported.
In the following table, the 01 means grayscale with depth<8, 31 means
indexed with depth<8, other numerals represent the color type, "T" means
@@ -3318,7 +3318,7 @@ Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.4.13beta02 are Y2K compliant. It is my belief that earlier
+upward through 1.4.13beta03 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has three year fields. One is a 2-byte unsigned integer that
diff --git a/libpng.3 b/libpng.3
index b7df584ae..359b160ea 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
.TH LIBPNG 3 "January 22, 2013"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.4.13beta02
+libpng \- Portable Network Graphics (PNG) Reference Library 1.4.13beta03
.SH SYNOPSIS
\fI\fB
@@ -887,7 +887,7 @@ Following is a copy of the libpng-manual.txt file that accompanies libpng.
.SH LIBPNG.TXT
libpng.txt - A description on how to use and modify libpng
- libpng version 1.4.13beta02 - January 22, 2013
+ libpng version 1.4.13beta03 - January 22, 2013
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2013 Glenn Randers-Pehrson
@@ -898,7 +898,7 @@ libpng.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.4.13beta02 - January 22, 2013
+ libpng versions 0.97, January 1998, through 1.4.13beta03 - January 22, 2013
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2010 Glenn Randers-Pehrson
@@ -1793,7 +1793,7 @@ things.
As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
added. It expands the sample depth without changing tRNS to alpha.
-As of libpng version 1.4.13beta02, not all possible expansions are supported.
+As of libpng version 1.4.13beta03, not all possible expansions are supported.
In the following table, the 01 means grayscale with depth<8, 31 means
indexed with depth<8, other numerals represent the color type, "T" means
@@ -4205,7 +4205,7 @@ Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.4.13beta02 are Y2K compliant. It is my belief that earlier
+upward through 1.4.13beta03 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has three year fields. One is a 2-byte unsigned integer that
@@ -4414,7 +4414,7 @@ the first widely used release:
1.4.11rc01 14 10411 14.so.14.11[.0]
1.4.11 14 10411 14.so.14.11[.0]
1.4.12 14 10412 14.so.14.12[.0]
- 1.4.13beta01-02 14 10413 14.so.14.13[.0]
+ 1.4.13beta01-03 14 10413 14.so.14.13[.0]
Henceforth the source version will match the shared-library minor
and patch numbers; the shared-library major version number will be
@@ -4470,7 +4470,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.4.13beta02 - January 22, 2013:
+Libpng version 1.4.13beta03 - January 22, 2013:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -4493,7 +4493,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.4.13beta02, January 22, 2013, are
+libpng versions 1.2.6, August 15, 2004, through 1.4.13beta03, January 22, 2013, are
Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
diff --git a/libpngpf.3 b/libpngpf.3
index b358ec3b2..5558d9972 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
.TH LIBPNGPF 3 "January 22, 2013"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.4.13beta02
+libpng \- Portable Network Graphics (PNG) Reference Library 1.4.13beta03
(private functions)
.SH SYNOPSIS
\fB#include <png.h>\fP
diff --git a/png.c b/png.c
index 01faa7a42..c23b54b8d 100644
--- a/png.c
+++ b/png.c
@@ -17,7 +17,7 @@
#include "pngpriv.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_4_13beta02 Your_png_h_is_not_version_1_4_13beta02;
+typedef version_1_4_13beta03 Your_png_h_is_not_version_1_4_13beta03;
/* Tells libpng that we have already handled the first "num_bytes" bytes
* of the PNG file signature. If the PNG data is embedded into another
@@ -547,13 +547,13 @@ png_get_copyright(png_const_structp png_ptr)
#else
#ifdef __STDC__
return ((png_charp) PNG_STRING_NEWLINE \
- "libpng version 1.4.13beta02 - January 22, 2013" PNG_STRING_NEWLINE \
+ "libpng version 1.4.13beta03 - January 22, 2013" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2010 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE);
#else
- return ((png_charp) "libpng version 1.4.13beta02 - January 22, 2013\
+ return ((png_charp) "libpng version 1.4.13beta03 - January 22, 2013\
Copyright (c) 1998-2010 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.");
diff --git a/pngconf.h b/pngconf.h
index faf1142ed..6751b0818 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.4.13beta02 - January 22, 2013
+ * libpng version 1.4.13beta03 - January 22, 2013
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngpriv.h b/pngpriv.h
index a5075d76f..e84b32dd6 100644
--- a/pngpriv.h
+++ b/pngpriv.h
@@ -1,7 +1,7 @@
/* pngpriv.h - private declarations for use inside libpng
*
- * libpng version 1.4.13beta02 - January 22, 2013
+ * libpng version 1.4.13beta03 - January 22, 2013
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngtest.c b/pngtest.c
index 76d385bef..62f745476 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -1702,4 +1702,4 @@ main(int argc, char *argv[])
}
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_4_13beta02 your_png_h_is_not_version_1_4_13beta02;
+typedef version_1_4_13beta03 your_png_h_is_not_version_1_4_13beta03;
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index b4fae05d1..75d1cd4dc 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.4.13beta02 - January 22, 2013
+libpng version 1.4.13beta03 - January 22, 2013
Copyright (c) 1998-2010 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index c3ffb7d74..67e2d9a94 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source and build
*
- * libpng version 1.4.13beta02 - January 22, 2013
+ * libpng version 1.4.13beta03 - January 22, 2013
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index 2ff4a0f48..1b1af0457 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,8 +1,8 @@
-Makefiles for libpng version 1.4.13beta02 - January 22, 2013
+Makefiles for libpng version 1.4.13beta03 - January 22, 2013
makefile.linux => Linux/ELF makefile
- (gcc, creates libpng14.so.14.1.4.13beta02)
+ (gcc, creates libpng14.so.14.1.4.13beta03)
makefile.gcc => Generic makefile (gcc, creates static libpng.a)
makefile.knr => Archaic UNIX Makefile that converts files with
ansi2knr (Requires ansi2knr.c from
@@ -20,7 +20,7 @@ Makefiles for libpng version 1.4.13beta02 - January 22, 2013
makefile.dec => DEC Alpha UNIX makefile
makefile.dj2 => DJGPP 2 makefile
makefile.elf => Linux/ELF makefile symbol versioning,
- (gcc, creates libpng14.so.14.1.4.13beta02)
+ (gcc, creates libpng14.so.14.1.4.13beta03)
makefile.freebsd => FreeBSD makefile
makefile.gcc => Generic gcc makefile
makefile.hpgcc => HPUX makefile using gcc
@@ -36,12 +36,12 @@ Makefiles for libpng version 1.4.13beta02 - January 22, 2013
makefile.os2 => OS/2 Makefile (gcc and emx, requires pngos2.def)
makefile.sco => For SCO OSr5 ELF and Unixware 7 with Native cc
makefile.sggcc => Silicon Graphics (gcc,
- creates libpng14.so.14.1.4.13beta02)
+ creates libpng14.so.14.1.4.13beta03)
makefile.sgi => Silicon Graphics IRIX makefile (cc, creates static lib)
makefile.solaris => Solaris 2.X makefile (gcc,
- creates libpng14.so.14.1.4.13beta02)
+ creates libpng14.so.14.1.4.13beta03)
makefile.so9 => Solaris 9 makefile (gcc,
- creates libpng14.so.14.1.4.13beta02)
+ creates libpng14.so.14.1.4.13beta03)
makefile.std => Generic UNIX makefile (cc, creates static libpng.a)
makefile.sunos => Sun makefile
makefile.32sunu => Sun Ultra 32-bit makefile
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index ba76de30f..3b5698dc9 100755
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
# Modeled after libxml-config.
-version=1.4.13beta02
+version=1.4.13beta03
prefix=""
libdir=""
libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index d333407c7..221679707 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@ includedir=@includedir@/libpng14
Name: libpng
Description: Loads and saves PNG files
-Version: 1.4.13beta02
+Version: 1.4.13beta03
Libs: -L${libdir} -lpng14
Cflags: -I${includedir}
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index 007942089..8c47a5149 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include/libpng14
LIB= png14
SHLIB_MAJOR= 0
-SHLIB_MINOR= 1.4.13beta02
+SHLIB_MINOR= 1.4.13beta03
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index f2a558d5e..b08eaeea9 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include
LIB= png
SHLIB_MAJOR= 3
-SHLIB_MINOR= 1.4.13beta02
+SHLIB_MINOR= 1.4.13beta03
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index 1030b8542..841b421f4 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@ LIBDIR= ${PREFIX}/lib
MANDIR= ${PREFIX}/man/cat
SHLIB_MAJOR= 0
-SHLIB_MINOR= 1.4.13beta02
+SHLIB_MINOR= 1.4.13beta03
LIB= png
SRCS= png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/png32ce.def b/scripts/png32ce.def
index e024150b2..2c1694ea2 100644
--- a/scripts/png32ce.def
+++ b/scripts/png32ce.def
@@ -15,7 +15,7 @@ LIBRARY lpngce
png_get_int_32
EXPORTS
-;Version 1.4.13beta02
+;Version 1.4.13beta03
png_build_grayscale_palette @1
; png_check_sig @2
png_chunk_error @3
diff --git a/scripts/pngos2.def b/scripts/pngos2.def
index 050a1489d..76a3c0981 100644
--- a/scripts/pngos2.def
+++ b/scripts/pngos2.def
@@ -2,7 +2,7 @@
; PNG.LIB module definition file for OS/2
;----------------------------------------
-; Version 1.4.13beta02
+; Version 1.4.13beta03
LIBRARY PNG
DESCRIPTION "PNG image compression library for OS/2"
diff --git a/scripts/pngwin.def b/scripts/pngwin.def
index 3745781aa..00120077a 100644
--- a/scripts/pngwin.def
+++ b/scripts/pngwin.def
@@ -5,7 +5,7 @@
LIBRARY
EXPORTS
-;Version 1.4.13beta02
+;Version 1.4.13beta03
png_build_grayscale_palette
png_chunk_error
png_chunk_warning
diff --git a/png.h b/png.h
index 1c6d56bb4..aaeb20bab 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.4.13beta02 - January 22, 2013
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.4.13beta02 - January 22, 2013: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -170,7 +170,7 @@
* 1.4.11rc01 14 10411 14.so.14.11[.0]
* 1.4.11 14 10411 14.so.14.11[.0]
* 1.4.12 14 10412 14.so.14.12[.0]
- * 1.4.13beta01-02 14 10413 14.so.14.13[.0]
+ * 1.4.13beta01-03 14 10413 14.so.14.13[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -202,7 +202,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.4.13beta02, January 22, 2013, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -320,7 +320,7 @@
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.4.13beta02 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -376,9 +376,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.4.13beta02"
+#define PNG_LIBPNG_VER_STRING "1.4.13beta03"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.4.13beta02 - January 22, 2013\n"
+ " libpng version 1.4.13beta03 - January 22, 2013\n"
#define PNG_LIBPNG_VER_SONUM 14
#define PNG_LIBPNG_VER_DLLNUM 14
@@ -391,7 +391,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 02
+#define PNG_LIBPNG_VER_BUILD 03
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -1502,7 +1502,7 @@ struct png_struct_def
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_4_13beta02;
+typedef png_structp version_1_4_13beta03;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.4.13beta02 - January 22, 2013
+ * libpng version 1.4.13beta03 - January 22, 2013
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.4.13beta02 - January 22, 2013: Glenn
+ * libpng versions 0.97, January 1998, through 1.4.13beta03 - January 22, 2013: Glenn
* See also "Contributing Authors", below.
*
@@ -202,7 +202,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.4.13beta02, January 22, 2013, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.4.13beta03, January 22, 2013, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -320,7 +320,7 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.4.13beta02 are Y2K compliant. It is my belief that earlier
+ * upward through 1.4.13beta03 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*